#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-lib
version:              1.6.4
visibility:           public
id:                   clash-lib-1.6.4-1ccHXZSAdMS8fhJoZrtnih
key:                  clash-lib-1.6.4-1ccHXZSAdMS8fhJoZrtnih
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2019, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - As a library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * The CoreHW internal language: SystemF + Letrec + Case-decomposition

    * The normalisation process that brings CoreHW in a normal form that can be
    converted to a netlist

    * Blackbox/Primitive Handling


    Front-ends (for: parsing, typecheck, etc.) are provided by separate packages:

    * <https://hackage.haskell.org/package/clash-ghc GHC/Haskell Frontend>

    * <https://github.com/christiaanb/Idris-dev Idris Frontend>


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  35469053336b2029b7d342d7b21a8eb8
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation.ClashLib Clash.Backend
    Clash.Backend.SystemVerilog Clash.Backend.VHDL
    Clash.Backend.Verilog Clash.Core.DataCon Clash.Core.EqSolver
    Clash.Core.Evaluator.Types Clash.Core.FreeVars
    Clash.Core.HasFreeVars Clash.Core.HasType Clash.Core.Literal
    Clash.Core.Name Clash.Core.PartialEval
    Clash.Core.PartialEval.AsTerm Clash.Core.PartialEval.Monad
    Clash.Core.PartialEval.NormalForm Clash.Core.Pretty
    Clash.Core.Subst Clash.Core.Term Clash.Core.TermInfo
    Clash.Core.TermLiteral Clash.Core.TermLiteral.TH Clash.Core.TyCon
    Clash.Core.Type Clash.Core.TysPrim Clash.Core.Util Clash.Core.Var
    Clash.Core.VarEnv Clash.Debug Clash.Driver Clash.Driver.Manifest
    Clash.Driver.Types Clash.Edalize.Edam Clash.Netlist
    Clash.Netlist.BlackBox Clash.Netlist.BlackBox.Parser
    Clash.Netlist.BlackBox.Types Clash.Netlist.BlackBox.Util
    Clash.Netlist.Id Clash.Netlist.Id.Common Clash.Netlist.Id.Internal
    Clash.Netlist.Id.SystemVerilog Clash.Netlist.Id.VHDL
    Clash.Netlist.Id.Verilog Clash.Netlist.Types Clash.Netlist.Util
    Clash.Normalize Clash.Normalize.PrimitiveReductions
    Clash.Normalize.Primitives Clash.Normalize.Strategy
    Clash.Normalize.Transformations Clash.Normalize.Transformations.ANF
    Clash.Normalize.Transformations.Case
    Clash.Normalize.Transformations.Cast
    Clash.Normalize.Transformations.DEC
    Clash.Normalize.Transformations.EtaExpand
    Clash.Normalize.Transformations.Inline
    Clash.Normalize.Transformations.Letrec
    Clash.Normalize.Transformations.MultiPrim
    Clash.Normalize.Transformations.Reduce
    Clash.Normalize.Transformations.SeparateArgs
    Clash.Normalize.Transformations.Specialize
    Clash.Normalize.Transformations.XOptimize Clash.Normalize.Types
    Clash.Normalize.Util Clash.Pretty Clash.Primitives.DSL
    Clash.Primitives.GHC.Int Clash.Primitives.GHC.Literal
    Clash.Primitives.GHC.Word Clash.Primitives.Intel.ClockGen
    Clash.Primitives.Sized.Signed Clash.Primitives.Sized.ToInteger
    Clash.Primitives.Sized.Vector Clash.Primitives.Types
    Clash.Primitives.Util Clash.Primitives.Verification
    Clash.Rewrite.Combinators Clash.Rewrite.Types Clash.Rewrite.Util
    Clash.Rewrite.WorkFree Clash.Unique Clash.Util Clash.Util.Eq
    Clash.Util.Graph Clash.Util.Interpolate Clash.Verification.Pretty
    Data.Aeson.Extra Data.Text.Prettyprint.Doc.Extra

hidden-modules:
    Clash.Annotations.TopEntity.Extra Data.IntMap.Extra Data.List.Extra
    Data.Map.Ordered.Extra Data.Monoid.Extra
    Data.Primitive.ByteArray.Extra Data.Set.Ordered.Extra
    Data.Text.Extra GHC.BasicTypes.Extra GHC.SrcLoc.Extra
    Paths_clash_lib

import-dirs:          /usr/lib/ghc-9.0.2/site-local/clash-lib-1.6.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/clash-lib-1.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clash-lib
hs-libraries:         HSclash-lib-1.6.4-1ccHXZSAdMS8fhJoZrtnih
depends:
    aeson-2.1.2.1-ACNZHhH4U2e67aZXZDgTOb
    aeson-pretty-0.8.9-5Tm0uL3qBZ1EdqAK7fmhpk
    ansi-terminal-0.11.4-30w7KBHfEQ9CygddjSQvBk array-0.5.4.0
    async-2.2.4-BdHoOnHsHdsApgNgZOPvuU
    attoparsec-0.14.4-IunVluIlg1j8NQqYaVddnF base-4.15.1.0
    base16-bytestring-1.0.2.0-BhRDuWK4BAQJZPnXghIxiI binary-0.8.8.0
    bytestring-0.10.12.1 clash-prelude-1.6.4-Do09HSxLpXSidqeHJke1e
    concurrent-supply-0.1.8-8ATJZJM3wK697fMdV8foCK containers-0.6.4.1
    cryptohash-sha256-0.11.102.1-GHCYwtJIWI57OAOzfqNLV4
    data-binary-ieee754-0.4.4-6nKeQnWkGoLJGejCHaRaWS
    data-default-0.7.1.1-8E5NGoO1gLxEpVTFDWBmYU deepseq-1.4.5.0
    directory-1.3.6.2 dlist-1.0-JalAZsGq1LOCqqdFHHEpoL
    exceptions-0.10.4 extra-1.7.14-1peTzRJ4sdJJmIV6KfSmoB
    filepath-1.4.2.1 ghc-9.0.2 ghc-bignum-1.1 ghc-boot-th-9.0.2
    hashable-1.4.3.0-ESEjVh9IF6l3kXlrvIyche
    haskell-src-meta-0.8.11-3BzFgwkoGUwEWXctmpXJaY
    hint-0.9.0.6-GMhsOo67MNg3AFqcLlzjgq
    interpolate-0.2.1-Fxh4oM7nhrh1N3HpOPELlm
    lens-5.2.3-A4jq1zRTTDpJs4RZBLF7I7 mtl-2.2.2
    ordered-containers-0.2.3-1tstpx5kksg3nCXqs5HGNP
    pretty-show-1.10-E9zv3yZn35Y9VpF8wkb8MR
    prettyprinter-1.7.1-3BN5DqkhAKiEdjSMkhtuTG
    primitive-0.7.4.0-8SmDsFCxSqgE7BzeiM7pZ4 template-haskell-2.17.0.0
    temporary-1.3-K1J0J5ny56o3ZcWKeBaVrQ
    terminal-size-0.3.4-35v8zhylKTKAMnavZT32Cm text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 trifecta-2.1.3-B7vQqpjcpDrIwxxZSrCLGt
    unordered-containers-0.2.19.1-J4eg8YowQRtEC3N7B7zfuy
    vector-0.13.0.0-HZxUYbi5cfB4SV8TkUpCM2
    vector-binary-instances-0.2.5.2-2YrcVWCFMda2czvGVaiHLu
    yaml-0.11.11.2-DyOIHZOyd45GJW05srfA9

haddock-interfaces:   /usr/share/doc/haskell-clash-lib/html/clash-lib.haddock
haddock-html:         /usr/share/doc/haskell-clash-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

